#include "Arduino.h"
#include <LiquidCrystal.h>
#include <BasicStepperDriver.h>

#include "Scenerunner.h"

Scenerunner::Scenerunner(LiquidCrystal *lcd, BasicStepperDriver *stepper, int pin_focus, int pin_shutter) {
  _lcd = lcd;
  _stepper = stepper;
  _pin_focus = pin_focus;
  _pin_shutter = pin_shutter;
}

void Scenerunner::start() {
  _lcd->clear();
  _lcd->print("Running...");
  steps_left = nSteps;
  runStep = RUN_SETTLE;
  runStepStart = millis();
}

void Scenerunner::_runHandler_off() {
  _lcd->setCursor(0, 1);
  _lcd->print("rS: OFF ");
}

void Scenerunner::_runHandler_settle() {
  _lcd->setCursor(0, 1);
  _lcd->print("rS: SETTLE ");
  if (millis() >= runStepStart + tSettle) {
    runStep = RUN_FOCUS;
    runStepStart = millis();
  }
}

void Scenerunner::_runHandler_focus() {
  _lcd->setCursor(0, 1);
  _lcd->print("rS: FOCUS ");
  if (millis() >= runStepStart + tFocus) {
    runStep = RUN_SHUTTER;
    runStepStart = millis();
  }
}

void Scenerunner::_runHandler_shutter() {
  _lcd->setCursor(0, 1);
  _lcd->print("rS: SHUTTER ");
  if (millis() >= runStepStart + tShutter) {
    runStep = RUN_MOVE;
    runStepStart = millis();
  }
}

void Scenerunner::_runHandler_move() {
  _lcd->setCursor(0, 1);
  _lcd->print("rS: MOVE ");
  if (millis() >= runStepStart + 1234) {
    // dummy wait time
    runStep = RUN_SETTLE;
    runStepStart = millis();
  }
}

void Scenerunner::_runHandler_return() {
  _lcd->setCursor(0, 1);
  _lcd->print("rS: RETURN ");
}

void Scenerunner::nextAction() {
  switch (runStep) {
    case RUN_OFF:
      _runHandler_off();
      break;
    case RUN_SETTLE:
      _runHandler_settle();
      break;
    case RUN_FOCUS:
      _runHandler_focus();
      break;
    case RUN_SHUTTER:
      _runHandler_shutter();
      break;
    case RUN_MOVE:
      _runHandler_move();
      break;
    case RUN_RETURN:
      _runHandler_return();
      break;
  }
}
